@@ -9,22 +9,22 @@
  * @copyright 2006 Sakamoto Kouichi
  * @license http://www.apache.org/licenses/LICENSE-2.0 Apache Software License 2.0
  * 
- * $Id: DocCommand.class.php 75 2006-04-06 13:35:12Z sakamoto $
+ * $Id: DocCommand.class.php 97 2006-04-23 10:05:16Z sakamoto $
  */
 
 /**
- * ҖԂ
- * Ԓl̃tH[}bg
+ * 著者名を返す
+ * 返値のフォーマットは
  * array(
- *   0 =>array(Җ1,'[AhX1'),
- *   1 =>array(Җ2,'[AhX2'),
+ *   0 =>array(著者名1,'メールアドレス1'),
+ *   1 =>array(著者名2,'メールアドレス2'),
  *   )
- *   : 
+ *   複数: 可
  * 
  * @package jp.servlet.AutoSOAP.Anno
  * @author Sakamoto Kouichi <sakamoto@servlet.sakura.ne.jp> 
  * @commandcode author
- * @format Җ<[AhX>
+ * @format 著者名<メールアドレス>
  */
 class AutoSOAP_Anno_AuthorCmd implements AutoSOAP_Anno_Command {
     private $result = null;
@@ -50,13 +50,13 @@ class AutoSOAP_Anno_AuthorCmd implements AutoSOAP_Anno_Command {
 } 
 
 /**
- * pbP[WԂ
- *   : s
+ * パッケージ名を返す
+ *   複数: 不可
  * 
  * @package jp.servlet.AutoSOAP.Anno
  * @author Sakamoto Kouichi <sakamoto@servlet.sakura.ne.jp> 
  * @commandcode package
- * @format pbP[W
+ * @format パッケージ名
  */
 class AutoSOAP_Anno_PackageCmd implements AutoSOAP_Anno_Command {
     private $result = null;
@@ -82,13 +82,13 @@ class AutoSOAP_Anno_PackageCmd implements AutoSOAP_Anno_Command {
 } 
 
 /**
- * TupbP[WԂ
- *   : s
+ * サブパッケージ名を返す
+ *   複数: 不可
  * 
  * @package jp.servlet.AutoSOAP.Anno
  * @author Sakamoto Kouichi <sakamoto@servlet.sakura.ne.jp> 
  * @commandcode subpackage
- * @format TupbP[W
+ * @format サブパッケージ名
  */
 class AutoSOAP_Anno_SubpackageCmd implements AutoSOAP_Anno_Command {
     private $result = null;
@@ -114,13 +114,13 @@ class AutoSOAP_Anno_SubpackageCmd implements AutoSOAP_Anno_Command {
 } 
 
 /**
- * JeS[pXԂ
- *   : s
+ * カテゴリーパスを返す
+ *   複数: 不可
  * 
  * @package jp.servlet.AutoSOAP.Anno
  * @author Sakamoto Kouichi <sakamoto@servlet.sakura.ne.jp> 
  * @commandcode category
- * @format JeS[pX
+ * @format カテゴリーパス
  */
 class AutoSOAP_Anno_CategoryCmd implements AutoSOAP_Anno_Command {
     private $result = null;
@@ -146,13 +146,13 @@ class AutoSOAP_Anno_CategoryCmd implements AutoSOAP_Anno_Command {
 } 
 
 /**
- * Rs[CgԂ
- *   : s
+ * コピーライトを返す
+ *   複数: 不可
  * 
  * @package jp.servlet.AutoSOAP.Anno
  * @author Sakamoto Kouichi <sakamoto@servlet.sakura.ne.jp> 
  * @commandcode copyright
- * @format Rs[Cg
+ * @format コピーライト
  */
 class AutoSOAP_Anno_CopyrightCmd implements AutoSOAP_Anno_Command {
     private $result = null;
@@ -178,13 +178,13 @@ class AutoSOAP_Anno_CopyrightCmd implements AutoSOAP_Anno_Command {
 } 
 
 /**
- * CZXԂ
- *   : s
+ * ライセンスを返す
+ *   複数: 不可
  * 
  * @package jp.servlet.AutoSOAP.Anno
  * @author Sakamoto Kouichi <sakamoto@servlet.sakura.ne.jp> 
  * @commandcode license
- * @format CZX
+ * @format ライセンス
  */
 class AutoSOAP_Anno_LicenseCmd implements AutoSOAP_Anno_Command {
     private $result = null;
@@ -210,13 +210,13 @@ class AutoSOAP_Anno_LicenseCmd implements AutoSOAP_Anno_Command {
 } 
 
 /**
- * TodoԂ
- *   : s
+ * Todoを返す
+ *   複数: 不可
  * 
  * @package jp.servlet.AutoSOAP.Anno
  * @author Sakamoto Kouichi <sakamoto@servlet.sakura.ne.jp> 
  * @commandcode todo
- * @format TodoRg
+ * @format Todoコメント
  */
 class AutoSOAP_Anno_TodoCmd implements AutoSOAP_Anno_Command {
     private $result = null;
@@ -242,13 +242,13 @@ class AutoSOAP_Anno_TodoCmd implements AutoSOAP_Anno_Command {
 } 
 
 /**
- * NԂ
- *   : s
+ * リンクを返す
+ *   複数: 不可
  * 
  * @package jp.servlet.AutoSOAP.Anno
  * @author Sakamoto Kouichi <sakamoto@servlet.sakura.ne.jp> 
  * @commandcode link
- * @format N
+ * @format リンク
  */
 class AutoSOAP_Anno_LinkCmd implements AutoSOAP_Anno_Command {
     private $result = null;
@@ -274,13 +274,13 @@ class AutoSOAP_Anno_LinkCmd implements AutoSOAP_Anno_Command {
 } 
 
 /**
- * `[gAԂ
- *   : s
+ * チュートリアルを返す
+ *   複数: 不可
  * 
  * @package jp.servlet.AutoSOAP.Anno
  * @author Sakamoto Kouichi <sakamoto@servlet.sakura.ne.jp> 
  * @commandcode tutorial
- * @format N
+ * @format リンク
  */
 class AutoSOAP_Anno_TutorialCmd implements AutoSOAP_Anno_Command {
     private $result = null;
@@ -306,13 +306,13 @@ class AutoSOAP_Anno_TutorialCmd implements AutoSOAP_Anno_Command {
 } 
 
 /**
- * o[WԂ
- *   : s
+ * バージョンを返す
+ *   複数: 不可
  * 
  * @package jp.servlet.AutoSOAP.Anno
  * @author Sakamoto Kouichi <sakamoto@servlet.sakura.ne.jp> 
- * @commandcode version@
- * @format o[W
+ * @commandcode version　
+ * @format バージョン
  */
 class AutoSOAP_Anno_VersionCmd implements AutoSOAP_Anno_Command {
     private $result = null;
@@ -338,13 +338,13 @@ class AutoSOAP_Anno_VersionCmd implements AutoSOAP_Anno_Command {
 } 
 
 /**
- * ǂ̃o[W瑶݂Ă̂Ԃ
- *   : s
+ * どのバージョンから存在しているのかを返す
+ *   複数: 不可
  * 
  * @package jp.servlet.AutoSOAP.Anno
  * @author Sakamoto Kouichi <sakamoto@servlet.sakura.ne.jp> 
  * @commandcode since
- * @format o[W
+ * @format バージョン
  */
 class AutoSOAP_Anno_SinceCmd implements AutoSOAP_Anno_Command {
     private $result = null;
@@ -370,13 +370,13 @@ class AutoSOAP_Anno_SinceCmd implements AutoSOAP_Anno_Command {
 } 
 
 /**
- * QƐԂ
- *   : 
+ * 参照先を返す
+ *   複数: 可
  * 
  * @package jp.servlet.AutoSOAP.Anno
  * @author Sakamoto Kouichi <sakamoto@servlet.sakura.ne.jp> 
- * @commandcode see@
- * @format ֘A֐
+ * @commandcode see　
+ * @format 関連関数
  */
 class AutoSOAP_Anno_SeeCmd implements AutoSOAP_Anno_Command {
     private $result = array();
@@ -395,13 +395,13 @@ class AutoSOAP_Anno_SeeCmd implements AutoSOAP_Anno_Command {
 } 
 
 /**
- * p~LĂꍇtrueԂA͒uAPIԂB
- *   : s
+ * 廃止が明記されている場合はtrueを返し、もしくは置き換わったAPIを返す。
+ *   複数: 不可
  * 
  * @package jp.servlet.AutoSOAP.Anno
  * @author Sakamoto Kouichi <sakamoto@servlet.sakura.ne.jp> 
- * @commandcode deprecated@
- * @format Rg
+ * @commandcode deprecated　
+ * @format コメント
  */
 class AutoSOAP_Anno_DeprecatedCmd implements AutoSOAP_Anno_Command {
     private $result = false;
@@ -420,12 +420,12 @@ class AutoSOAP_Anno_DeprecatedCmd implements AutoSOAP_Anno_Command {
 } 
 
 /**
- * I[oCg֎~̗LԂ
- *   : 
+ * オーバライトが禁止の有無を返す
+ *   複数: 可
  * 
  * @package jp.servlet.AutoSOAP.Anno
  * @author Sakamoto Kouichi <sakamoto@servlet.sakura.ne.jp> 
- * @commandcode final@
+ * @commandcode final　
  * @format 
  */
 class AutoSOAP_Anno_FinalCmd implements AutoSOAP_Anno_Command {
@@ -445,12 +445,12 @@ class AutoSOAP_Anno_FinalCmd implements AutoSOAP_Anno_Command {
 } 
 
 /**
- * ÓIȂ̂Ԃ
- *   : 
+ * 静的なものか返す
+ *   複数: 可
  * 
  * @package jp.servlet.AutoSOAP.Anno
  * @author Sakamoto Kouichi <sakamoto@servlet.sakura.ne.jp> 
- * @commandcode static@
+ * @commandcode static　
  * @format 
  */
 class AutoSOAP_Anno_StaticCmd implements AutoSOAP_Anno_Command {
@@ -470,12 +470,12 @@ class AutoSOAP_Anno_StaticCmd implements AutoSOAP_Anno_Command {
 } 
 
 /**
- * 邩Ԃ
- *   : 
+ * 無視するか返す
+ *   複数: 可
  * 
  * @package jp.servlet.AutoSOAP.Anno
  * @author Sakamoto Kouichi <sakamoto@servlet.sakura.ne.jp> 
- * @commandcode ignore@
+ * @commandcode ignore　
  * @format 
  */
 class AutoSOAP_Anno_IgnoreCmd implements AutoSOAP_Anno_Command {
@@ -495,8 +495,8 @@ class AutoSOAP_Anno_IgnoreCmd implements AutoSOAP_Anno_Command {
 } 
 
 /**
- * AbstractNXԂ
- *   : 
+ * Abstractクラスか返す
+ *   複数: 可
  * 
  * @package jp.servlet.AutoSOAP.Anno
  * @author Sakamoto Kouichi <sakamoto@servlet.sakura.ne.jp> 
@@ -520,19 +520,19 @@ class AutoSOAP_Anno_AbstractCmd implements AutoSOAP_Anno_Command {
 } 
 
 /**
- * p[^AzzŕԂ
- * Ԓl̃tH[}bg
+ * パラメータを連想配列で返す
+ * 返値のフォーマットは
  * array(
- *   p[^1=>array('^','Rg'),
- *   p[^2=>array('^','Rg'),
- *   p[^3=>array('^','Rg'),
+ *   パラメータ名1=>array('型','コメント'),
+ *   パラメータ名2=>array('型','コメント'),
+ *   パラメータ名3=>array('型','コメント'),
  *   )
- *   : 
+ *   複数: 可
  * 
  * @package jp.servlet.AutoSOAP.Anno
  * @author Sakamoto Kouichi <sakamoto@servlet.sakura.ne.jp> 
  * @commandcode param
- * @format ^ p[^ Rg
+ * @format 型 パラメータ名 コメント
  */
 class AutoSOAP_Anno_ParamCmd implements AutoSOAP_Anno_Command {
     private $result = array();
@@ -556,19 +556,19 @@ class AutoSOAP_Anno_ParamCmd implements AutoSOAP_Anno_Command {
 } 
 
 /**
- * Tvt@CꏊԂ
+ * サンプルファイル場所を返す
  * array(
- *   0 => array('t@CpX','Rg'),
- *   1 => array('t@CpX','Rg'),
+ *   0 => array('ファイルパス','コメント'),
+ *   1 => array('ファイルパス','コメント'),
  *     .
  *     .
  *   )
- *   : 
+ *   複数: 可
  * 
  * @package jp.servlet.AutoSOAP.Anno
  * @author Sakamoto Kouichi <sakamoto@servlet.sakura.ne.jp> 
  * @commandcode example
- * @format t@CpX Rg
+ * @format ファイルパス コメント
  */
 class AutoSOAP_Anno_ExampleCmd implements AutoSOAP_Anno_Command {
     private $result = array();
@@ -592,19 +592,19 @@ class AutoSOAP_Anno_ExampleCmd implements AutoSOAP_Anno_Command {
 } 
 
 /**
- * O[oϐ̏Ԃ
+ * グローバル変数の情報を返す
  * array(
- *   'ϐ' => array('^','Rg'),
- *   'ϐ' => array('^','Rg'),
+ *   '変数名' => array('型','コメント'),
+ *   '変数名' => array('型','コメント'),
  *     .
  *     .
  *   )
- *   : 
+ *   複数: 可
  * 
  * @package jp.servlet.AutoSOAP.Anno
  * @author Sakamoto Kouichi <sakamoto@servlet.sakura.ne.jp> 
  * @commandcode global
- * @format ^ ϐ Rg
+ * @format 型 変数名 コメント
  */
 class AutoSOAP_Anno_GlobalCmd implements AutoSOAP_Anno_Command {
     private $result = array();
@@ -628,19 +628,19 @@ class AutoSOAP_Anno_GlobalCmd implements AutoSOAP_Anno_Command {
 } 
 
 /**
- * ÓIϐ̏Ԃ
+ * 静的変数の情報を返す
  * array(
- *   'ϐ' => array('^','Rg'),
- *   'ϐ' => array('^','Rg'),
+ *   '変数名' => array('型','コメント'),
+ *   '変数名' => array('型','コメント'),
  *     .
  *     .
  *   )
- *   : 
+ *   複数: 可
  * 
  * @package jp.servlet.AutoSOAP.Anno
  * @author Sakamoto Kouichi <sakamoto@servlet.sakura.ne.jp> 
  * @commandcode staticvar
- * @format ^ ϐ Rg
+ * @format 型 変数名 コメント
  */
 class AutoSOAP_Anno_StaticvarCmd implements AutoSOAP_Anno_Command {
     private $result = array();
@@ -664,19 +664,19 @@ class AutoSOAP_Anno_StaticvarCmd implements AutoSOAP_Anno_Command {
 } 
 
 /**
- * pÕNXNX̕ϐԂ
+ * 利用する外部のクラスやクラスの変数を返す
  * array(
- *   'NX' => 'Rg',
- *   'ϐ' => 'Rg',
+ *   'クラス名' => 'コメント',
+ *   '変数名' => 'コメント',
  *     .
  *     .
  *   )
- *   : 
+ *   複数: 可
  * 
  * @package jp.servlet.AutoSOAP.Anno
  * @author Sakamoto Kouichi <sakamoto@servlet.sakura.ne.jp> 
  * @commandcode uses
- * @format ϐ Rg
+ * @format 変数名 コメント
  */
 class AutoSOAP_Anno_UsesCmd implements AutoSOAP_Anno_Command {
     private $result = array();
@@ -700,17 +700,17 @@ class AutoSOAP_Anno_UsesCmd implements AutoSOAP_Anno_Command {
 } 
 
 /**
- * ϐ̌^Ԃ
+ * 変数の型を返す
  * array(
- *   0 => '^',
- *   1 => 'Rg',
+ *   0 => '型',
+ *   1 => 'コメント',
  *   )
- *   : s
+ *   複数: 不可
  * 
  * @package jp.servlet.AutoSOAP.Anno
  * @author Sakamoto Kouichi <sakamoto@servlet.sakura.ne.jp> 
  * @commandcode var
- * @format ^ Rg
+ * @format 型 コメント
  */
 class AutoSOAP_Anno_VarCmd implements AutoSOAP_Anno_Command {
     private $result = null;
@@ -737,25 +737,25 @@ class AutoSOAP_Anno_VarCmd implements AutoSOAP_Anno_Command {
 } 
 
 /**
- * Ԃ
+ * 制限名を返す
  * array(
- *    Ώۂ̕ϐ(Ȃ'') => ,
- *       E
- *       E
- *       E
+ *    対象の変数(なければ'') => 制限名,
+ *       ・
+ *       ・
+ *       ・
  *   )
- *   : 
+ *   複数: 可
  * 
  * @package jp.servlet.AutoSOAP.Anno
  * @author Sakamoto Kouichi <sakamoto@servlet.sakura.ne.jp> 
  * @commandcode restriction_name
- * @format 
+ * @format 制限名
  */
 class AutoSOAP_Anno_RestrictionNameCmd implements AutoSOAP_Anno_Command {
     private $result = null;
     public function getCode()
     {
-        return 'restriction_name';
+        return array('rname','restriction_name');
     } 
     public function getResult()
     {
@@ -773,25 +773,25 @@ class AutoSOAP_Anno_RestrictionNameCmd implements AutoSOAP_Anno_Command {
 } 
 
 /**
- * V^ƔhԂ
+ * 新しい型と派生元を返す
  * array(
- *     => ^,
- *       E
- *       E
- *       E
+ *    制限名 => 型,
+ *       ・
+ *       ・
+ *       ・
  *   )
- *   : 
+ *   複数: 可
  * 
  * @package jp.servlet.AutoSOAP.Anno
  * @author Sakamoto Kouichi <sakamoto@servlet.sakura.ne.jp> 
  * @commandcode restriction_type
- * @format ^ 
+ * @format 型 制限名
  */
 class AutoSOAP_Anno_RestrictionTypeCmd implements AutoSOAP_Anno_Command {
     private $result = null;
     public function getCode()
     {
-        return 'restriction_type';
+        return array('rtype','restriction_type');
     } 
     public function getResult()
     {
@@ -809,31 +809,31 @@ class AutoSOAP_Anno_RestrictionTypeCmd implements AutoSOAP_Anno_Command {
 } 
 
 /**
- * Ԃ
+ * 制限を返す
  * array(
- *    Ώۂ̕ϐ(Ȃ'') => array(
+ *    対象の変数(なければ'') => array(
  *      0 => array(
- *        @ => l
+ *        制限方法 => 制限値
  *      ),
  *      1 => array(
- *        @ => l
+ *        制限方法 => 制限値
  *      ),
- *       E
- *       E
- *       E
+ *       ・
+ *       ・
+ *       ・
  *   )
- *   : 
+ *   複数: 可
  * 
  * @package jp.servlet.AutoSOAP.Anno
  * @author Sakamoto Kouichi <sakamoto@servlet.sakura.ne.jp> 
  * @commandcode restriction
- * @format [^[Qbg@]@ l
+ * @format [ターゲット@]制限方法 制限値
  */
 class AutoSOAP_Anno_RestrictionCmd implements AutoSOAP_Anno_Command {
     private $result = null;
     public function getCode()
     {
-        return 'restriction';
+        return array('r','restriction');
     } 
     public function getResult()
     {
@@ -851,18 +851,18 @@ class AutoSOAP_Anno_RestrictionCmd implements AutoSOAP_Anno_Command {
 } 
 
 /**
- * ԒlԂB
- * Ԓl̃tH[}bg
+ * 返値を返す。
+ * 返値のフォーマットは
  * array(
- *   0 => array('^','^','^',...),
- *   1 => 'Rg'
+ *   0 => array('型','型','型',...),
+ *   1 => 'コメント'
  *   )
- *   : s
+ *   複数: 不可
  * 
  * @package jp.servlet.AutoSOAP.Anno
  * @author Sakamoto Kouichi <sakamoto@servlet.sakura.ne.jp> 
- * @commandcode return@
- * @format Ԓľ^(or l)|Ԓľ^(or l)... Rg
+ * @commandcode return　
+ * @format 返値の型(or 値)|返値の型(or 値)... コメント
  */
 class AutoSOAP_Anno_ReturnCmd implements AutoSOAP_Anno_Command {
     private $result = null;
@@ -889,13 +889,13 @@ class AutoSOAP_Anno_ReturnCmd implements AutoSOAP_Anno_Command {
 } 
 
 /**
- * ANZXCqԂ
- *   : s
+ * アクセス修飾子を返す
+ *   複数: 不可
  * 
  * @package jp.servlet.AutoSOAP.Anno
  * @author Sakamoto Kouichi <sakamoto@servlet.sakura.ne.jp> 
  * @commandcode access
- * @format ANZXCq(private|protected|public)
+ * @format アクセス修飾子(private|protected|public)
  */
 class AutoSOAP_Anno_AccessCmd implements AutoSOAP_Anno_Command {
     private $result = null;
@@ -920,4 +920,68 @@ class AutoSOAP_Anno_AccessCmd implements AutoSOAP_Anno_Command {
     } 
 } 
 
+/**
+ * 検証時のエラーメッセージを返す
+ *   複数: 不可
+ * 
+ * @package jp.servlet.AutoSOAP.Anno
+ * @author Sakamoto Kouichi <sakamoto@servlet.sakura.ne.jp> 
+ * @commandcode validate_error
+ * @format エラーメッセージ
+ */
+class AutoSOAP_Anno_ValidateErrorCmd implements AutoSOAP_Anno_Command {
+    private $result = null;
+    public function getCode()
+    {
+        return 'validate_error';
+    } 
+    public function getResult()
+    {
+        return $this->result;
+    } 
+    public function execute($value)
+    {
+        $matchs = array();
+        if (!is_null($this->result)) {
+            trigger_error('It has already been set.(' . __CLASS__ . ')', E_USER_WARNING);
+        } else if (preg_match("/(?:\S.*)/i", $value, $matchs)) {
+            $this->result = $matchs[0];
+        } else {
+            trigger_error('It failed in the match.(' . __CLASS__ . ')', E_USER_WARNING);
+        } 
+    } 
+} 
+
+
+/**
+ * エンコードの指定
+ *   複数: 不可
+ * 
+ * @package jp.servlet.AutoSOAP.Anno
+ * @author Sakamoto Kouichi <sakamoto@servlet.sakura.ne.jp> 
+ * @commandcode encoding
+ * @format エンコード名
+ */
+class AutoSOAP_Anno_EncodingCmd implements AutoSOAP_Anno_Command {
+    private $result = null;
+    public function getCode()
+    {
+        return 'encoding';
+    } 
+    public function getResult()
+    {
+        return $this->result;
+    } 
+    public function execute($value)
+    {
+        $matchs = array();
+        if (!is_null($this->result)) {
+            trigger_error('It has already been set.(' . __CLASS__ . ')', E_USER_WARNING);
+        } else if (preg_match("/(?:\S.*)/i", $value, $matchs)) {
+            $this->result = $matchs[0];
+        } else {
+            trigger_error('It failed in the match.(' . __CLASS__ . ')', E_USER_WARNING);
+        } 
+    } 
+} 
 ?>
\ No newline at end of file
