@@ -9,12 +9,19 @@
  * @copyright 2006 Sakamoto Kouichi
  * @license http://www.apache.org/licenses/LICENSE-2.0 Apache Software License 2.0
  * 
- * $Id: AutoSOAP.php 51 2006-03-31 10:12:28Z sakamoto $
+ * $Id: AutoSOAP.php 118 2006-04-26 13:37:28Z sakamoto $
  */
+include_once(dirname(__FILE__) . "/AutoSOAP/Define.class.php");
+include_once(dirname(__FILE__) . "/AutoSOAP/Session.class.php");
+include_once(dirname(__FILE__) . "/AutoSOAP/Global.class.php");
+
 include_once(dirname(__FILE__) . "/AutoSOAP/Server.class.php");
 include_once(dirname(__FILE__) . "/AutoSOAP/Service.class.php");
-include_once(dirname(__FILE__) . "/AutoSOAP/Session.class.php");
+
 include_once(dirname(__FILE__) . "/AutoSOAP/Logger.class.php");
 include_once(dirname(__FILE__) . "/AutoSOAP/Filter.class.php");
-include_once(dirname(__FILE__) . "/AutoSOAP/Types.class.php");
-?>
\ No newline at end of file
+
+interface AutoSOAP {
+    const VERSION="1.0.0";	
+}
+?>
