@@ -9,27 +9,27 @@
  * @copyright 2006 Sakamoto Kouichi
  * @license http://www.apache.org/licenses/LICENSE-2.0 Apache Software License 2.0
  * 
- * $Id: Logger.class.php 74 2006-04-05 14:29:06Z sakamoto $
+ * $Id: Logger.class.php 96 2006-04-21 14:51:52Z sakamoto $
  */
 
 /**
- * SoapServerMOC^[tF[X
+ * SoapServerロギングインターフェース
  * 
  * @package jp.servlet.AutoSOAP.server.logger
  * @author Sakamoto Kouichi <sakamoto@servlet.sakura.ne.jp> 
  */
 interface AutoSOAP_Logger {
     /**
-     * Ȍo
+     * ログの出力
      * 
      * @access public 
-     * @param AutoSOAP_Service $service s̃T[rX
-     * @param integer $errno G[ԍ
-     * @param string $errstr G[bZ[W
-     * @param string $errfile G[ot@CpX
-     * @param string $errline G[os
+     * @param AutoSOAP_Service $service 実行中のサービス
+     * @param integer $errno エラー番号
+     * @param string $errstr エラーメッセージ
+     * @param string $errfile エラーを出したファイルパス
+     * @param string $errline エラーを出した行数
      */
-    public function output(AutoSOAP_Service $service, $errno, $errstr, $errfile, $errline);
+    public function output($service, $errno, $errstr, $errfile, $errline);
 } 
 
 ?>
\ No newline at end of file
