@@ -9,74 +9,74 @@
  * @copyright 2006 Sakamoto Kouichi
  * @license http://www.apache.org/licenses/LICENSE-2.0 Apache Software License 2.0
  * 
- * $Id: Server.class.php 78 2006-04-11 13:51:37Z sakamoto $
+ * $Id: Server.class.php 104 2006-04-25 15:06:20Z sakamoto $
  */
 
 /**
- * AutoSOAPT[o{
+ * AutoSOAPサーバ本体
  * 
  * @package jp.servlet.AutoSOAP
  * @author Sakamoto Kouichi <sakamoto@servlet.sakura.ne.jp> 
  */
 class AutoSOAP_Server {
     /**
-     * 񋟂T[rX̏
+     * 提供されるサービスの情報
      * 
-     * @var AutoSOAP _Service
+     * @var AutoSOAP_Service
      */
     private $service;
 
     /**
-     * MONX
+     * ロギング制御クラス
      * 
-     * @var AutoSOAP _Logger
+     * @var AutoSOAP_Logger
      */
     private $logger;
 
     /**
-     * ϊ̃GR[h
+     * 変換後のエンコード
      * 
      * @var string 
      */
     private $to_encoding = null;
 
     /**
-     * ϊÕGR[h
+     * 変換前のエンコード
      * 
      * @var string 
      */
     private $from_encoding = null;
 
     /**
-     * SoapServerIuWFNg
+     * SoapServerオブジェクト
      * 
      * @var SoapServer 
      */
     private $server;
 
     /**
-     * \bh"schemaValidate"̃G[bZ[W
+     * メソッド"schemaValidate"のエラーメッセージ
      * 
      * @var string 
      */
     private static $error_schemaValidate;
 
     /**
-     * tB^[
+     * フィルター
      * 
      * @var array 
      */
     private static $filters;
 
     /**
-     * CX^XIuWFNg
+     * インスタンスオブジェクト
      * 
-     * @var AutoSOAP _Server
+     * @var AutoSOAP_Server
      */
     private static $instance;
 
     /**
-     * RXgN^
+     * コンストラクタ
      * 
      * @access private 
      * @return void 
@@ -87,10 +87,10 @@ class AutoSOAP_Server {
     } 
 
     /**
-     * CX^̎擾
+     * インスタンの取得
      * 
      * @access public 
-     * @return AutoSOAP _Server
+     * @return AutoSOAP_Server
      */
     static public function getInstance()
     {
@@ -103,7 +103,7 @@ class AutoSOAP_Server {
     } 
 
     /**
-     * SOAPbZ[W؂B
+     * SOAPメッセージを検証する。
      * 
      * @static 
      * @access private 
@@ -114,12 +114,7 @@ class AutoSOAP_Server {
     static private function schemaValidate(&$soap_message, $xsd_file, $error_msg)
     {
         $aDOM = new DOMDocument('1.0', 'UTF-8');
-        $patterns = array("/[^\s\:\"\']+\:encodingStyle=[\"\'][^\"\'\s]*[\"\']/i" ,
-            "/([^<>\'\"\s]=[\'\"]http:\/\/www.w3.org)\/1999\/(XMLSchema)/i",
-            );
-        $replacements = array("", "\\1/2001/\\2");
-
-        $aDOM -> loadXML(preg_replace($patterns, $replacements, $soap_message));
+        $aDOM -> loadXML(preg_replace("/[^\s\:\"\']+\:encodingStyle=[\"\'][^\"\'\s]*[\"\']/i", "", substr($soap_message,0,1024), 1).substr($soap_message,1024));
 
         $old = set_error_handler(array(self :: $instance, "schemaValidate_error_handler"));
         $result = $aDOM -> schemaValidate($xsd_file);
@@ -136,8 +131,8 @@ class AutoSOAP_Server {
     } 
 
     /**
-     * NGXgꂽ\bhԂ
-     * sꍇ́ANULLԂ
+     * リクエストされたメソッド名を返す
+     * 失敗した場合は、NULLを返す
      * 
      * @static 
      * @access private 
@@ -170,10 +165,10 @@ class AutoSOAP_Server {
     } 
 
     /**
-     * MONXZbg
+     * ロギングクラスをセットする
      * 
      * @access public 
-     * @param AutoSOAP $ _Logger $logger
+     * @param AutoSOAP_Logger $logger
      * @return boolean 
      */
     public function setLogger(AutoSOAP_Logger $logger)
@@ -182,21 +177,21 @@ class AutoSOAP_Server {
     } 
 
     /**
-     * T[rXZbg
+     * サービスをセットする
      * 
      * @access public 
-     * @param AutoSOAP $ _Service $service
+     * @param AutoSOAP_Service $service
      * @param integer $load_mode 
      * @return boolean 
      */
     public function setService(AutoSOAP_Service $service)
     {
         $this -> service = $service; 
-        // T[rXNX̃CN[h
+        // サービスクラスのインクルード
         $this -> service -> include_class();
 
         /**
-         * WSDLXSDt@C𐶐
+         * WSDLとXSDファイルを生成する
          */
         $timestamp = $this -> service -> getTimestamp();
         if ($this -> service -> need_update_wsdl_file()) {
@@ -208,7 +203,7 @@ class AutoSOAP_Server {
     } 
 
     /**
-     * T[rX̎s
+     * サービスの実行
      * 
      * @access public 
      * @return boolean 
@@ -219,82 +214,52 @@ class AutoSOAP_Server {
             global $HTTP_RAW_POST_DATA;
             $request = &$HTTP_RAW_POST_DATA;
         } 
-        // T[o
+        // サーバ初期化
         $this -> server = null; 
-        // \bh݂̑̃`FbN
+        // メソッドの存在のチェック
         $web_method = self :: getSoapMethodName($request, $this -> service -> getNamespace());
         if (is_null($web_method)) {
             return false;
         } 
-        // tB^[s
+        // フィルター実行
         foreach($this -> filters as $filter) {
-            // ZbVꍞ
-            $filter_class_name = get_class($filter);
-            $ref = new ReflectionClass($filter_class_name);
-            $filter_static_properties = $ref -> getStaticProperties();
-            foreach ($filter_static_properties as $key => $val) {
-                $matches = array();
-                if (preg_match("/^(?:__global_sess|__sess_(\S+))$/i", $key, $matches)) {
-                    switch ($matches[0]) {
-                    case '__global_sess' :
-                        eval($filter_class_name . '::$' . $key . ' = AutoSOAP_Session::getSession(null);');
-                        break;
-                    default :
-                        eval($filter_class_name . '::$' . $key . ' = AutoSOAP_Session::getSession("' . $matches[1] . '");');
-                        break;
-                    } 
-                }
-            }
+            // グローバル変数を編み込む
+            AutoSOAP_Global::knitForClass(get_class($filter));
+
             $filter -> execute($this -> service, $web_method);
         } 
   
-        // Ó̃`FbN
+        // 妥当性のチェック
         if (!is_null($this -> service -> getXsdPath())) {
             $error_msg = $this -> getValidateError($web_method);
             if (false === self :: schemaValidate($request, $this -> service -> getXsdPath(), $error_msg)) {
                 return false;
             } 
         } 
-        // T[rXNX̃CN[h
+        // サービスクラスのインクルード
         $this -> service -> include_class(); 
-        // SOAPT[o
+        // SOAPサーバ生成
         $this -> server = new SoapServer($this -> service -> getWsdlPath(),
             array('soap_version' => SOAP_1_1,
                 'classmap' => $this -> getClassmap()
                 )
             ); 
-        // NX擾
+        // クラス名取得
         $class_name = $this -> service -> getClassName(); 
-        // ZbVꍞ
-        $ref = new ReflectionClass($class_name);
-        $static_properties = $ref -> getStaticProperties();
-        foreach ($static_properties as $key => $val) {
-            $matches = array();
-            if (preg_match("/^(?:__global_sess|__sess(?:_(\S+))?)$/i", $key, $matches)) {
-                switch ($matches[0]) {
-                case '__global_sess' :
-                    eval($class_name . '::$' . $key . ' = AutoSOAP_Session::getSession(null);');
-                    break;
-                case '__sess' :
-                    eval($class_name . '::$' . $key . ' = AutoSOAP_Session::getSession("' . $class_name . '");');
-                    break;
-                default :
-                    eval($class_name . '::$' . $key . ' = AutoSOAP_Session::getSession("' . $matches[1] . '");');
-                    break;
-                } 
-            } 
-        } 
-        // T[rX̎s
+        // グローバル変数を編み込む
+        AutoSOAP_Global::knitForClass($class_name);
+
+        // サービスの実行
         $this -> server -> setClass($class_name);
         $this -> server -> handle($request); 
-        // T[oZbg
+        // サーバリセット
         $this -> server = null;
 
         return true;
     } 
 
     /**
-     * WSDLt@C\
+     * WSDLファイルを表示する
      * 
      * @access public 
      * @return void 
@@ -307,9 +272,9 @@ class AutoSOAP_Server {
     } 
 
     /**
-     * WSDLt@C쐬
+     * WSDLファイルを作成する
      * 
-     * @access private 
+     * @access private
      * @return boolean 
      */
     private function make_wsdl_file($timestamp)
@@ -322,22 +287,20 @@ class AutoSOAP_Server {
         $result = file_put_contents($this -> service -> getWsdlPath(), $engine -> getResult($this -> to_encoding, $this -> from_encoding));
         if ($result && !is_null($timestamp)) {
             touch($this -> service -> getWsdlPath(), $timestamp);
-        } 
-        // NX}bvĂ
-        $content = "<?php\n";
-        $content .= "\$_=" . var_export($engine -> getClassmap(), true) . ";\n";
-        $content .= "\$_validate_errors=" . var_export($engine -> getValidateErrorMap(), true) . ";\n";
-        $content .= "?>";
-        $result_c = file_put_contents($this -> service -> getClassmapPath(), $content);
+        }
+        
+        // その他の情報も生成しておく
+        $content = $engine -> exportOptions();
+        $result_c = file_put_contents($this -> service -> getOptionPath(), $content);
         if ($result_c && !is_null($timestamp)) {
-            touch($this -> service -> getClassmapPath(), $timestamp);
+            touch($this -> service -> getOptionPath(), $timestamp);
         } 
 
         return $result;
     } 
 
     /**
-     * XSDt@C쐬
+     * XSDファイルを作成する
      * 
      * @access private 
      * @return boolean 
@@ -367,31 +330,31 @@ class AutoSOAP_Server {
     } 
 
     /**
-     * NX}bv擾
+     * クラスマップを取得する
      * 
      * @access public 
      * @return array 
      */
     private function getClassmap()
     {
-        include($this -> service -> getClassmapPath());
-        return (isset($_))?$_ : array();
+        include($this -> service -> getOptionPath());
+        return (isset($_classmap))?$_classmap : array();
     } 
 
     /**
-     * ؎̃G[bZ[W擾
+     * 検証時のエラーメッセージを取得する
      * 
      * @access public 
      * @return array 
      */
     private function getValidateError($method)
     {
-        include($this -> service -> getClassmapPath());
+        include($this -> service -> getOptionPath());
         return (isset($_validate_errors[$method]))?$_validate_errors[$method] : null;
     } 
 
     /**
-     * GR[hݒ肷
+     * エンコードを設定する
      * 
      * @access public 
      * @return void 
@@ -403,10 +366,10 @@ class AutoSOAP_Server {
     } 
 
     /**
-     * tB^[Zbg
+     * フィルターをセットする
      * 
      * @access public 
-     * @param AutoSOAP $ _Filter $filter
+     * @param AutoSOAP_Filter $filter
      */
     public function appendFilter(AutoSOAP_Filter $filter)
     {
@@ -414,28 +377,45 @@ class AutoSOAP_Server {
     } 
 
     /**
-     * SOAPpG[nhO
+     * 現在の情報をかえす
+     * 
+     * @access public 
+     * @param AutoSOAP_Filter $filter
+     */
+    public function getInfo()
+    {
+        return get_object_vars($this);
+    } 
+
+    /**
+     * SOAP用エラーハンドリング
      * 
      * @access public 
      * @return void 
      */
     public function soap_error_handler($errno, $errstr, $errfile, $errline)
     { 
-        // E_STRICT͖
+        // E_STRICTは無視する
         if (E_STRICT === $errno) {
             return;
         } 
 
         $result = false; 
-        // Oo
+        // ログ出力
         if ($this -> logger instanceof AutoSOAP_Logger) {
             $result = $this -> logger -> output($this -> service, $errno, $errstr, $errfile, $errline);
         } 
-        // TRUEꍇASOAPG[bZ[W͏o͂ȂB
+        // TRUEだった場合、SOAPエラーメッセージは出力しない。
         if (true === $result) {
             return ;
         } 
-        // SOAPG[bZ[Wo
+
+        // E_NOTICE or E_USER_NOTICEだった場合、SOAPエラーメッセージは出力しない。
+        if (E_NOTICE === $errno || E_USER_NOTICE === $errno) {
+            return;
+        } 
+
+        // SOAPエラーメッセージを出力
         $errortype = array (
             E_ERROR => "Error",
             E_WARNING => "Warning",
@@ -466,7 +446,7 @@ class AutoSOAP_Server {
     } 
 
     /**
-     * schemaValidatepSOAPpG[nhO
+     * schemaValidate用SOAP用エラーハンドリング
      * 
      * @access public 
      * @return void 
