@@ -9,35 +9,38 @@
  * @copyright 2006 Sakamoto Kouichi
  * @license http://www.apache.org/licenses/LICENSE-2.0 Apache Software License 2.0
  * 
- * $Id: class2SoapXsdVisitor.class.php 78 2006-04-11 13:51:37Z sakamoto $
+ * $Id: class2SoapXsdVisitor.class.php 97 2006-04-23 10:05:16Z sakamoto $
  */
 
 /**
- * NXSOAPbZ[WؗpXSDf[^ւ̕ϊprW^[NX
+ * クラス→SOAPメッセージ検証用XSDデータへの変換用ビジタークラス
  * 
  * @package jp.servlet.AutoSOAP
  * @author Sakamoto Kouichi <sakamoto@servlet.sakura.ne.jp> 
  */
 class AutoSOAP_class2SoapXsdVisitor implements AutoSOAP_ReflectionVisitor {
-    // SOAPf[^Ǘ
+    // SOAPデータ生成管理
     private $_class2soap;
 
+    // エンコード
+    private $_encoding = null;
+
     /**
-     * 
+     * 初期化
      */
     public function init($target_uri, $soapenv_uri = null, $soapenc_uri = null)
     {
         $schema = AutoSOAP_XMLogic_SchemaFactory :: getInstance();
 
         /**
-         * XSD̑g̍쐬
+         * XSDの大枠の作成
          */
         $root = $schema -> createRoot($target_uri);
         $class2xsd = new AutoSOAP_class2xsdVisitor();
         $class2xsd -> init($root);
 
         /**
-         * SOAPGu[uXL[}C|[g
+         * SOAPエンブローブスキーマをインポート
          */
         $xml = AutoSOAP_XMLogic_XMLFactory :: getInstance();
         if (is_null($soapenv_uri))
@@ -54,15 +57,16 @@ class AutoSOAP_class2SoapXsdVisitor implements AutoSOAP_ReflectionVisitor {
     } 
 
     /**
-     * ʂԂ
+     * 結果を返す
      */
     public function getResult($to_encoding = null, $from_encoding = null)
     {
+        $encoding = (is_null($from_encoding)) ? $this->_encoding : $from_encoding;
         return $this -> _class2soap -> getResult($to_encoding, $from_encoding);
     } 
 
     /**
-     * q
+     * 子を処理する
      */
     public function visitChildren(AutoSOAP_ReflectionChildren $children)
     {
@@ -70,20 +74,35 @@ class AutoSOAP_class2SoapXsdVisitor implements AutoSOAP_ReflectionVisitor {
     } 
 
     /**
-     * NX
+     * クラスを処理する
      */
     public function visitClass(AutoSOAP_ReflectionAccept $class)
     {
         /**
-         * C^[tF[XV^CN[h
+         * インターフェースから新しい型をインクルードする
          */
         $this -> _class2soap -> createNewTypes($class); 
-        // \bhǉ
+
+        /**
+         * アノテーションの取得
+         */ 
+        $annotation = AutoSOAP_Anno :: parseReflector($class);
+
+        // エンコードを取得
+        $this->_encoding = $annotation->execute(new AutoSOAP_Anno_EncodingCmd()); 
+
+        // 新しい型の取得
+        $elemTypes = AutoSOAP_ElementType :: createByClass($annotation);
+        foreach($elemTypes as $newtype => $elemType) {
+            $this -> _class2soap -> getElementInfo('', $elemType, array('new_type' => $newtype));
+        }
+
+        // メソッド追加
         $class -> getMethods() -> accept($this);
     } 
 
     /**
-     * \bhǉ
+     * メソッドを追加する
      */
     public function visitMethod(AutoSOAP_ReflectionAccept $method)
     {
@@ -92,17 +111,17 @@ class AutoSOAP_class2SoapXsdVisitor implements AutoSOAP_ReflectionVisitor {
         } 
 
         $method_name = $method -> getName(); 
-        // XMLXL[}^ONX
+        // XMLスキーマタグ生成クラス
         $schema = AutoSOAP_XMLogic_SchemaFactory :: getInstance();
 
         /**
-         * NGXg\bhǉ
+         * リクエストメソッド追加
          */
         $request_name = $method_name . "Request";
         $request = $schema -> createComplexType($request_name);
 
         /**
-         * p[^ǉ
+         * パラメータ追加
          */
         $parameters = $method -> getParameters() -> accept($this);
         if (0 < count($parameters)) {
@@ -116,7 +135,7 @@ class AutoSOAP_class2SoapXsdVisitor implements AutoSOAP_ReflectionVisitor {
         $this -> _class2soap -> appendXML($request);
 
         /**
-         * ʖǉĂ
+         * 別名も追加しておく
          */
         $alias = $schema -> createComplexType($method_name);
         $alias_tmp = $schema -> createComplexContent();
@@ -125,7 +144,7 @@ class AutoSOAP_class2SoapXsdVisitor implements AutoSOAP_ReflectionVisitor {
         $this -> _class2soap -> appendXML($alias);
 
         /**
-         * X|X\bhǉ
+         * レスポンスメソッド追加
          */
         $response_name = $method_name . "Response";
         $response = $this -> _class2soap -> getDataTypeElement($response_name, $this -> _class2soap -> getReturnInfo());
@@ -133,7 +152,7 @@ class AutoSOAP_class2SoapXsdVisitor implements AutoSOAP_ReflectionVisitor {
     } 
 
     /**
-     * 
+     * 引数を処理する
      */
     public function visitParameter(AutoSOAP_ReflectionAccept $param)
     {
@@ -144,32 +163,32 @@ class AutoSOAP_class2SoapXsdVisitor implements AutoSOAP_ReflectionVisitor {
     } 
 
     /**
-     * vpeB
+     * プロパティを処理する
      */
     public function visitProperty(AutoSOAP_ReflectionAccept $property)
     {
     } 
     /**
-     * ֐
+     * 関数を処理する
      */
     public function visitFunction(AutoSOAP_ReflectionAccept $func)
     {
     } 
     /**
-     * IuWFNg
+     * オブジェクトを処理する
      */
     public function visitObject(AutoSOAP_ReflectionAccept $object)
     {
     } 
     /**
-     * GNXeV
+     * エクステンションを処理する
      */
     public function visitExtension(AutoSOAP_ReflectionAccept $extension)
     {
     } 
 
     /**
-     * SOAPf[^ǗԂ
+     * SOAPデータ生成管理を返す
      */
     public function getClass2soap()
     {
