@@ -9,7 +9,7 @@
  * @copyright 2006 Sakamoto Kouichi
  * @license http://www.apache.org/licenses/LICENSE-2.0 Apache Software License 2.0
  * 
- * $Id: class2soap.php 78 2006-04-11 13:51:37Z sakamoto $
+ * $Id: class2soap.php 97 2006-04-23 10:05:16Z sakamoto $
  */
 include_once(dirname(dirname(__FILE__)) . "/XMLogic/Visitor.class.php");
 include_once(dirname(dirname(__FILE__)) . "/XMLogic/XMLogic.php");
@@ -28,7 +28,7 @@ include_once(dirname(__FILE__) . "/class2wsdlVisitor.class.php");
 include_once(dirname(__FILE__) . "/ElementType.class.php");
 
 /**
- * NXWSDLf[^ւ̕ϊpNX
+ * クラス→WSDLデータへの変換用クラス
  * 
  * @package jp.servlet.AutoSOAP
  * @author Sakamoto Kouichi <sakamoto@servlet.sakura.ne.jp> 
@@ -50,7 +50,7 @@ class AutoSOAP_class2wsdl {
     } 
 
     /**
-     * NX}bvԂ
+     * クラスマップを返す
      */
     public function getClassmap()
     {
@@ -58,16 +58,35 @@ class AutoSOAP_class2wsdl {
     } 
 
     /**
-     * ؗpG[bZ[W}bvԂ
+     * 検証用エラーメッセージマップを返す
      */
     public function getValidateErrorMap()
     {
         return $this -> visitor -> getValidateErrorMap();
     } 
+
+    /**
+     * オプションデータをエクスポートする
+     */
+    public function exportOptions()
+    {
+        $content = "<?php\n";
+        $content .= "\$_classmap="        . var_export($this -> getClassmap(), true)         . ";\n";
+        $content .= "\$_validate_errors=" . var_export($this -> getValidateErrorMap(), true) . ";\n";
+        $content .= "?>";
+
+        $encoding = $this -> visitor -> getEncoding();
+
+        if(is_null($encoding)) {
+            return mb_convert_encoding($content, 'UTF-8');
+        } else {
+            return mb_convert_encoding($content, 'UTF-8', $encoding);
+        }
+    }
 } 
 
 /**
- * NXSOAPbZ[WؗpXSDf[^ւ̕ϊNX
+ * クラス→SOAPメッセージ検証用XSDデータへの変換クラス
  * 
  * @package jp.servlet.AutoSOAP
  * @author Sakamoto Kouichi <sakamoto@servlet.sakura.ne.jp> 
@@ -90,19 +109,19 @@ class AutoSOAP_class2SoapXsd {
 } 
 
 /**
- * SOAPf[^ǗNX
+ * SOAPデータ生成管理クラス
  * 
  * @package jp.servlet.AutoSOAP
  * @author Sakamoto Kouichi <sakamoto@servlet.sakura.ne.jp> 
  */
 class AutoSOAP_class2soap {
-    // ^[Qbgl[Xy[X
+    // ターゲットネームスペース
     private $_Target_uri; 
-    // ClassXSDNX
+    // Class→XSD化クラス
     private $_class2xsd; 
-    // XML[g
+    // XMLルート
     private $_root; 
-    // \bh̃Ame[V
+    // メソッドのアノテーション
     private $_method_annotation; 
     
     private $_elemTypes;
@@ -115,7 +134,7 @@ class AutoSOAP_class2soap {
     } 
 
     /**
-     * XMLIuWFNgǉ
+     * XMLオブジェクトを追加する
      */
     public function appendXML(AutoSOAP_XMLogic_Obj $elem, $num = -1)
     {
@@ -123,7 +142,7 @@ class AutoSOAP_class2soap {
     } 
 
     /**
-     * NX}bvԂ
+     * クラスマップを返す
      */
     public function getClassmap()
     {
@@ -131,7 +150,7 @@ class AutoSOAP_class2soap {
     } 
 
     /**
-     * Ԃ
+     * を返す
      */
     public function getTargetURI()
     {
@@ -139,7 +158,7 @@ class AutoSOAP_class2soap {
     } 
 
     /**
-     * \bhɋLqĂ^̎擾
+     * メソッドに記述されてある型情報の取得
      */
     public function createMethodInfo(AutoSOAP_ReflectionAccept $method)
     {
@@ -147,28 +166,28 @@ class AutoSOAP_class2soap {
         $this -> _elemTypes = null;
 
         $method_name = $method -> getName(); 
-        // ANZX public oȂꍇ͐ÓI֐̏ꍇ́AǉȂ
+        // アクセス権が public 出ない場合もしくは静的関数の場合は、追加しない
         if (!$method -> isPublic() || $method -> isStatic()) {
             return null;
         } 
 
         /**
-         * \bh̓Ɂu__vꍇ́AǉȂ
+         * メソッド名の頭に「__」があった場合は、追加しない
          */
         if (preg_match("/^__/i", $method_name)) {
             return null;
         } 
 
         /**
-         * Ame[V̎擾
+         * アノテーションの取得
          */
         $this -> _method_annotation = AutoSOAP_Anno :: parseReflector($method); 
-        // ANZX擾
+        // アクセス制御を取得
         $anno_access = $this -> _method_annotation -> execute(new AutoSOAP_Anno_AccessCmd());
         if ('public' !== $anno_access && !is_null($anno_access)) {
             return null;
         } 
-        // ÓI擾
+        // 静的かを取得
         $anno_static = $this -> _method_annotation -> execute(new AutoSOAP_Anno_StaticCmd());
         if (true === $anno_static) {
             return null;
@@ -184,16 +203,16 @@ class AutoSOAP_class2soap {
     } 
 
     /**
-     * ؎̃G[bZ[WԂ
+     * 検証時のエラーメッセージを返す
      */
     public function getValidateError()
     { 
-        // ؎̃G[bZ[W擾
+        // 検証時のエラーメッセージを取得
         return $this -> _method_annotation -> execute(new AutoSOAP_Anno_ValidateErrorCmd());
     } 
 
     /**
-     * Ԓl̏Ԃ
+     * 返値の情報を返す
      */
     public function getReturnInfo()
     {
@@ -204,7 +223,7 @@ class AutoSOAP_class2soap {
     } 
 
     /**
-     * 
+     * 引数を処理する
      */
     public function getParameterInfo($param_name)
     {
@@ -215,7 +234,7 @@ class AutoSOAP_class2soap {
     } 
 
     /**
-     * ʂԂ
+     * 結果を返す
      */
     public function getResult($to_encoding = null, $from_encoding = null)
     {
@@ -227,19 +246,19 @@ class AutoSOAP_class2soap {
     } 
 
     /**
-     * V^̐
+     * 新しい型の生成
      */
     public function createNewTypes(AutoSOAP_ReflectionAccept $class)
     {
         /**
-         * C^[tF[XV^CN[h
+         * インターフェースから新しい型をインクルードする
          */
         $interfaces = $class -> getInterfaces();
         $interfaces -> accept($this -> _class2xsd);
     } 
 
     /**
-     * ^ẅׂ̃GgԂB
+     * 型指定の為のエレメントを返す。
      */
     public function getDataTypeElement($name, AutoSOAP_ElementType $elemType, $options = null)
     {
@@ -247,7 +266,7 @@ class AutoSOAP_class2soap {
     } 
 
     /**
-     * ^𐶐ׂ̏擾
+     * 型を生成する為の情報を取得する
      */
     public function getElementInfo($name, AutoSOAP_ElementType $elemType, $options)
     {
@@ -255,7 +274,7 @@ class AutoSOAP_class2soap {
     } 
 
     /**
-     * ̃IvVԂ
+     * 引数のオプションを返す
      */
     static public function getParamOptions(AutoSOAP_ReflectionAccept $param)
     {
@@ -270,7 +289,7 @@ class AutoSOAP_class2soap {
     } 
 
     /**
-     * q
+     * 子を処理する
      */
     static public function visitChildren(AutoSOAP_ReflectionVisitor $visitor, AutoSOAP_ReflectionChildren $children)
     {
